@@ -43,3 +43,23 @@ class Session(object):
             self.collector = StatsCollector(session=self)
 
         return self.collector
+
+    def Hypervisor(self):
+        return Hypervisor(self)
+
+class Hypervisor(object):
+    '''Convenience class around libxc primitives.'''
+    def __init__(self, session):
+        self.session = session
+
+    def dmesg(self, clear=False):
+        return self.session.xc.readconsolering(clear)
+
+    def physinfo(self):
+        return self.session.xc.physinfo()
+
+    def xeninfo(self):
+        return self.session.xc.xeninfo()
+
+    def info(self):
+        return dict(list(self.physinfo().items()) + list(self.xeninfo().items()))
